"""
AuroraPay
"""

from .client import AuroraPayClient
from .exceptions import (
    AuroraPayError,
    ValidationError,
    OrderCreationError,
    OrderNotFoundError,
    UnauthorizedError,
    InactiveShopError,
    ForbiddenError,
)
from .models import (
    PaymentMethod,
    PaymentStatus,
    CreateOrderRequest,
    CreateOrderResponse,
    PaymentStatusResponse,
)

__version__ = "1.0.0"
__all__ = [
    "AuroraPayClient",
    "AuroraPayError",
    "ValidationError",
    "OrderCreationError",
    "OrderNotFoundError",
    "UnauthorizedError",
    "InactiveShopError",
    "ForbiddenError",
    "PaymentMethod",
    "PaymentStatus",
    "CreateOrderRequest",
    "CreateOrderResponse",
    "PaymentStatusResponse",
]
